SearchSection class final

One heading-delimited chunk of a page.

Constructors

SearchSection({String? heading, String? anchor, String body = ''})
const
SearchSection.fromJson(Map<String, Object?> json)
factory

Properties

anchor String?
The heading's slug, for deep-linking a result to #anchor. Null when heading is null.
final
body String
final
hashCode int
The hash code for this object.
no setterinherited
heading String?
Null for the leading section before a page's first heading.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited